==> migrate_wizard-1.0.10-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWDefaultFieldCollectionItem.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'default_node' field type.
 *
 * @FieldType(
 *   id = "default_field_collection_item",
 * )
 */
class FieldTypeMWDefaultFieldCollectionItem extends FieldTypeMWBase {

  public static function getMigrationConfig(&$wildcard_yml_config, $array_config, $origin_node, $default_langcode = NULL, $langcode = NULL, $translation = FALSE) {
    $suffix = '';
    if($translation){
      $suffix = '_'.$langcode;
    }
    $wildcard_yml_config['id'] = $origin_node.$suffix;
    $wildcard_yml_config['label'] = $origin_node.$suffix;
    $wildcard_yml_config['langcode'] = $langcode;
    $wildcard_yml_config['migration_group'] = getenv('MIGRATE_DB_NAME');
    $wildcard_yml_config['migration_tags'][0] = getenv('MIGRATE_DB_NAME');
    $wildcard_yml_config['source']['field_name'] = $origin_node;
    $wildcard_yml_config['source']['name'] = $origin_node;
    $wildcard_yml_config['source']['origin_type'] = $array_config['origin_type'];
    $wildcard_yml_config['source']['entity_type'] = $array_config['origin_type'];
    $wildcard_yml_config['source']['constants']['langcode'] = $langcode;
    $wildcard_yml_config['source']['constants']['default_langcode'] = $default_langcode;
    if($translation){
      $wildcard_yml_config['source']['bundle'] = $origin_node.$suffix;
      $wildcard_yml_config['source']['translations'] = TRUE;
      $wildcard_yml_config['source']['constants']['translations'] = TRUE;
      $wildcard_yml_config['process']['id'][] = [
        'plugin' => 'mw_fc_translation_migration_lookup',
        'migration' => [$origin_node],
        'source' => 'id_lookup',
        'no_stub' => TRUE,
      ];
      $wildcard_yml_config['process']['langcode'] = 'language';
      $wildcard_yml_config['destination']['default_bundle'] = $origin_node;
      $wildcard_yml_config['destination']['translations'] = TRUE;
      $wildcard_yml_config['destination']['langcode'] = $langcode;
    }
    $wildcard_yml_config['process']['type'][] = [
      'plugin' => 'default_value',
      'default_value' => array_key_first($array_config),
    ];
    $wildcard_yml_config['process']['created'] = 'created';
    if (isset($array_config['preserve_nid']) && $array_config['preserve_nid'] && !$translation) {
      $wildcard_yml_config['process']['nid'] = 'nid';
    }
  }
}

==> migrate_wizard-1.0.12-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWDefaultFieldCollectionItem.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'default_node' field type.
 *
 * @FieldType(
 *   id = "default_field_collection_item",
 * )
 */
class FieldTypeMWDefaultFieldCollectionItem extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $array_config, $origin_node, $default_langcode = NULL, $langcode = NULL, $translation = FALSE) {
    $suffix = '';
    if($translation){
      $suffix = '_'.$langcode;
    }
    $wildcard_yml_config['id'] = $origin_node.$suffix;
    $wildcard_yml_config['label'] = $origin_node.$suffix;
    $wildcard_yml_config['process']['langcode'][] = [
        'plugin' => 'skip_on_empty',
        'source' => 'language',
        'method' => 'row',
    ];
    $wildcard_yml_config['migration_group'] = getenv('MIGRATE_DB_NAME');
    $wildcard_yml_config['migration_tags'][0] = getenv('MIGRATE_DB_NAME');
    $wildcard_yml_config['source']['field_name'] = $origin_node;
    $wildcard_yml_config['source']['name'] = $origin_node;
    $wildcard_yml_config['source']['origin_type'] = $array_config['origin_type'];
    $wildcard_yml_config['source']['entity_type'] = $array_config['origin_type'];
    $wildcard_yml_config['source']['constants']['langcode'] = $langcode;
    $wildcard_yml_config['source']['constants']['default_langcode'] = $default_langcode;
    if($translation){
      $wildcard_yml_config['source']['bundle'] = $origin_node.$suffix;
      $wildcard_yml_config['source']['translations'] = TRUE;
      $wildcard_yml_config['source']['constants']['translations'] = TRUE;
      $wildcard_yml_config['process']['id'][] = [
        'plugin' => 'skip_on_empty',
        'source' => 'id_lookup',
        'method' => 'row',
      ];
      $wildcard_yml_config['process']['id'][] = [
        'plugin' => 'mw_fc_translation_migration_lookup',
        'migration' => [$origin_node],
        'no_stub' => TRUE,
      ];
      $wildcard_yml_config['process']['langcode'] = 'language';
      $wildcard_yml_config['destination']['default_bundle'] = $origin_node;
      $wildcard_yml_config['destination']['translations'] = TRUE;
      $wildcard_yml_config['destination']['langcode'] = $langcode;
    }
    $wildcard_yml_config['process']['type'][] = [
      'plugin' => 'default_value',
      'default_value' => array_key_first($array_config),
    ];
    $wildcard_yml_config['process']['created'] = 'created';
    if (isset($array_config['preserve_nid']) && $array_config['preserve_nid'] && !$translation) {
      $wildcard_yml_config['process']['nid'] = 'nid';
    }
  }
}
